// Function: exp(-a*x)/(1-exp(-a*x))
// This is a negative exponential, normalized to unit integral.
// Its parameter controls the concentration near the origin.

public class NegExpFunction extends Function {

    private double a, coef;
    private int ncalls=0;

    NegExpFunction(double a){
        this.a = a;
        coef = a/(1 - Math.exp(-a)); 
    }

    public double getValue(double x)
    {
        ncalls++;
        return coef*Math.exp(-x*a);
    } 

    public int getNCalls() {
        return ncalls;
    }

    public String toString(){
        return "exp(-"+a+"x)"+"/(1-exp(-" + a +"x))";
    }
}
